summaryrefslogtreecommitdiff
path: root/src/mesa/drivers/dri/r300/compiler/radeon_program.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/drivers/dri/r300/compiler/radeon_program.h')
-rw-r--r--src/mesa/drivers/dri/r300/compiler/radeon_program.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mesa/drivers/dri/r300/compiler/radeon_program.h b/src/mesa/drivers/dri/r300/compiler/radeon_program.h
index 56740643f2..ee4fe8192e 100644
--- a/src/mesa/drivers/dri/r300/compiler/radeon_program.h
+++ b/src/mesa/drivers/dri/r300/compiler/radeon_program.h
@@ -197,7 +197,7 @@ static inline void reset_srcreg(struct rc_src_register* reg)
/**
* A transformation that can be passed to \ref radeonLocalTransform.
*
* The function will be called once for each instruction.
* It has to either emit the appropriate transformed code for the instruction
@@ -214,9 +214,9 @@ struct radeon_program_transformation {
void *userData;
};
-void radeonLocalTransform(
+void rc_local_transform(
struct radeon_compiler *c,
- struct radeon_program_transformation* transformations);
+ void *user);
unsigned int rc_find_free_temporary(struct radeon_compiler * c);
@@ -197,7 +197,7 @@ static inline void reset_srcreg(struct rc_src_register* reg)
/**
- * A transformation that can be passed to \ref radeonLocalTransform.
+ * A transformation that can be passed to \ref rc_local_transform.
*
* The function will be called once for each instruction.